#
# spec file for package rtl88x2bu
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rtl88x2bu
Version:        5.8.7.1+git20250512.1800958
Release:        2.4
Summary:        Kernel driver for Realtek 88x2bu wifi cards
License:        GPL-2.0-only
Group:          System/Kernel
URL:            https://github.com/cilynx/rtl88x2bu
ExcludeArch:    s390x
Source0:        %{name}-%{version}.tar
Source1:        %{name}-preamble
# PATCH-FIX-OPENSUSE rtl88x2bu_nodate_time.patch
Patch0:         rtl88x2bu_nodate_time.patch
# PATCH-FIX-OPENSUSE fix-backported-update_mgmt_frame_registrations.patch
Patch1:         fix-backported-update_mgmt_frame_registrations.patch
BuildRequires:  %{kernel_module_package_buildreqs}
BuildRequires:  bc
BuildRequires:  kernel-macros
BuildRequires:  module-init-tools

%{!?kernel_module_directory:%define kernel_module_directory /lib/modules}

%description
Kernel driver for Realtek 88x2bu wifi cards

The sources were obtained from https://github.com/cilynx/rtl88x2bu, which adapts the official driver
released by Realtek to build on recent kernels.

%package KMP
Summary:        Kernel driver for Realtek rtl88x2bu wifi cards
Group:          System/Kernel

%description KMP
Kernel driver for Realtek 88x2bu wifi cards

The sources were obtained from https://github.com/cilynx/rtl88x2bu, which adapts the official driver
released by Realtek to build on recent kernels.

%kernel_module_package -p %{name}-preamble

%prep
%setup -q
sed -i '/EXTRA_CFLAGS += -O2/d' Makefile
sed -i '/EXTRA_LDFLAGS += --strip-debug/d' Makefile
%patch -P 0 -p0
%if 0%{?sle_version} == 150300
%patch -P 1 -p0
%endif

set -- *
mkdir source
mv "$@" source/
mkdir obj

%build
%ifarch %{arm}
export ARCH=arm
%endif
%ifarch aarch64
export ARCH=arm64
%endif
%ifarch %{ppc} ppc64 ppc64le
export ARCH=powerpc
%endif
%ifarch riscv64
export ARCH=riscv
%endif

for flavor in %{flavors_to_build} ; do
    rm -rf obj/$flavor
    cp -a source obj/$flavor
    pushd obj/$flavor
    sed -i -e "s,^KSRC := /lib/modules/\$(KVER)/build$,KSRC := %{_prefix}/src/linux-obj/%{_target_cpu}/$flavor," Makefile
    %make_build ${ARCH:+ARCH=$ARCH}
    popd
done

%install
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=%{kernel_module_package_moddir}
kernel_version=`uname -r | sed -e "s/-[^-]*$//"`
echo ${kernel_version}
for flavor in %{flavors_to_build} ; do
    pushd obj/$flavor
    install -d %{buildroot}/lib/modules/${kernel_version}-${flavor}/${INSTALL_MOD_DIR}/
    mkdir -p %{buildroot}%{kernel_module_directory}/${kernel_version}-${flavor}/${INSTALL_MOD_DIR}/
    install -p -m 644 88x2bu.ko %{buildroot}%{kernel_module_directory}/${kernel_version}-${flavor}/${INSTALL_MOD_DIR}/
    popd
done

%files
%license source/LICENSE

%changelog
* Tue Jun 10 2025 Andreas Schwab <schwab@suse.de>
- Use correct ARCH
* Wed May 14 2025 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 5.8.7.1+git20250512.1800958:
  * fix: Use ccflags-y instead of EXTRA_CFLAGS
  * fix: Switch to use timer_delete_sync
  * docs: Explain new options of ./deploy.sh in README
  * fix: Switch branches, as -n means variable has value
  * chore: Drop leftover comment
  * docs: Add examples section to --help
  * feat: Do not remove driver for all kernels
  * feat: Add verbosity flag to CLI
  * feat: Add simple command line parsing
  * feat: Find available Kernels with helper function
  * chore: Move `get_version` to better place
  * chore: Move `remove_driver` to better place
  * feat: Extend deploy script to install for all kernels
  * Add additional argument to cfg80211_rtw_get_txpower
* Wed Jan 29 2025 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 5.8.7.1+git20250126.efe396c:
  * Add additional argument to cfg80211_rtw_set_monitor_channel
- Update to version 5.8.7.1+git20241216.45ca59c:
  * Add v6.10.3 to compatibility list
* Wed May 22 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 5.8.7.1+git20240521.287e766:
  * Fix build for Linux v6.9
  * Remove puncturing bitmap from function calls
  * Suppress stringop-overread
  * Remove useless if-guard
  * Rewrite section regarding Unknown symbol errors
* Fri Mar 22 2024 eyadlorenzo@gmail.com
- Update to version 5.8.7.1+git20240314.8c9afc1:
  * Add v6.8.0 to compatibility list
  * Add v6.7.2 to compatibility list
  * Following unnesting of attribute
  * Disable new warnings
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Jan 15 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 5.8.7.1+git20240108.476ef38:
  * Add v6.5.5 and v6.6.1 to compatibility list
  * Change order of #if and #else
  * Follow renaming of _settings to _update
  * Adapt type of change_beacon
  * Add v6.5.2 to compatibility list
  * Use tee to redirect content to root file
  * Improve wording minorly
* Tue Aug 22 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 5.8.7.1+git20230713.6789143:
  * Update notion of confirmed compatibility
- Remove recompression service in _service
* Fri Jun 30 2023 eyadlorenzo@gmail.com
- Update to version 5.8.7.1+git20230628.0be6fb4:
  * Add Linux 6.4.0 to confirmed builds
* Sun Jun  4 2023 eyadlorenzo@gmail.com
- Update to version 5.8.7.1+git20230518.41e9827:
  * Extend section of confirmed builds
* Fri May  5 2023 eyadlorenzo@gmail.com
- Update to version 5.8.7.1+git20230424.3de9861:
  * Add TP-Link Archer T3U Nano (2357:012e)
  * Pass default puncturing bitmap to cfg80211_ch_switch_notify
* Thu Feb  9 2023 eyadlorenzo@gmail.com
- Update to version 5.8.7.1+git20221213.549257e:
  * Extend section about secure boot
  * Switch to get_random_u32
  * Fix compilation for v6.0 again
  * Pass default link_id to cfg80211_ch_switch_started_notify
  * Drop the weight argument from netif_napi_add
  * Add link_id parameter to various key operations
  * Use nproc to build driver using multithreads
  * Adding a note about secure boot
* Sat Apr  9 2022 tejas.guruswamy@opensuse.org
- Update to version 5.8.7.1+git20220324.1751f39:
  * Use mm_segment_t only on Linux < 5.10.0
  * Remove unrequired usages of mm_segment_t
  * Map PDE_DATA to pde_data
  * Rename complete_and_exit to kthread_complete_and_exit
  * Fix build since dev_addr constification
  * Revert "Use `--cvs-exclude` instead of hardcoding `.git/`"
  * Use `--cvs-exclude` instead of hardcoding `.git/`
  * Disable IPX for Linux kernel >= 5.15
  * Rework architecture detection Fixes #170
  * Replace fall-through comments by attributes
* Sat Mar  5 2022 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Fix missing %%kernel_module_directory macro on 15.3
* Mon Oct  4 2021 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Add fix-backported-update_mgmt_frame_registrations.patch for build on 15.3 kernel
* Mon Oct  4 2021 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Initial package from https://github.com/cilynx/rtl88x2bu
